@@ -159,7 +159,8 @@ class StateBase(IOBase, metaclass=ABCMeta):
         This property modifies the normal `_state_attributes` and adds information
         necessary for restoring the class using :meth:`StateBase.from_data`.
         """
-        attrs = copy.deepcopy(self._state_attributes)
+        # make a copy since we add additional fields below
+        attrs = self._state_attributes.copy()
 
         # add some additional information
         attrs["__class__"] = self.__class__.__name__
@@ -261,26 +262,63 @@ class StateBase(IOBase, metaclass=ABCMeta):
         else:
             raise ValueError(f"Incompatible state class {cls_name}")
 
-    def copy(self: TState, data=None) -> TState:
+    def copy(self: TState, method: str, data=None) -> TState:
         """create a copy of the state
 
+        There are several methods of copying the state:
+
+        `clean`:
+            Makes a copy of the state by gathering its contents using
+            :meth:`~StateBase.__getstate__`, makeing a copy of only the actual data and
+            then instantiating a new state class, using :meth:`~StateBase.__setstate__`
+            to restore the state. Since a new object is created, all data not captured
+            by `__getstate__` (like internal caches) are lost!
+        `shallow`:
+            Performs a shallow copy of all attributes of the class. This is simply
+            copying the entire :attr:`__dict__`
+        `data`:
+            Like `shallow`, but additionally makes a deep copy of the state data (stored
+            in the :attr:`_state_data`, which typically is aliased by :attr:`data`).
+
         Args:
-            data: Data to be used instead of the one in the current state
+            method (str):
+                Determines whether a `clean`, `shallow`, or `data` copy is performed.
+                See description above for details.
+            data:
+                Data to be used instead of the one in the current state. This data is
+                used as is and not copied!
 
         Returns:
             A copy of the current state object
         """
-        # use __getstate__ to get data necessary to re-create data
-        state = self.__getstate__()
-        if data is not None:
-            state["data"] = data
-
-        # create a copy of the state
-        state = copy.deepcopy(state)
-
-        # use __setstate__ to set data on new object
+        # create a new object of the same class without any attributes
         obj = self.__class__.__new__(self.__class__)
-        obj.__setstate__(state)
+
+        if method == "clean":
+            # make clean copy by re-initializing state with copy of relevant attributes
+            state = copy.deepcopy(self.__getstate__())  # copy current state
+            if data is not None:
+                state["data"] = data
+            # use __setstate__ to set data on new object
+            obj.__setstate__(state)
+
+        elif method == "shallow":
+            # (shallow) copy of all attributes of current state, including `data`
+            obj.__dict__ = self.__dict__.copy()
+            if data is not None:
+                obj._state_data = data
+
+        elif method == "data":
+            # (shallow) copy of all attributes of current state, except `data`, which is
+            # copied using a deep-copy
+            obj.__dict__ = self.__dict__.copy()
+            if data is None:
+                obj._state_data = copy.deepcopy(self._state_data)
+            else:
+                obj._state_data = data
+
+        else:
+            raise ValueError(f"Unknown copy method {method}")
         return obj
 
     def _state_write_zarr_attributes(
